close all

trans=@(q)  [2*q(1,:);q(2,:);0.5*q(3,:).*(1+0.5*sin(2*pi*q(1,:)))];
% Build mesh from .geo file 
meshfile=gmsh.buildmesh3ds('sphere8surf',40);                    
Th=siMesh(meshfile);
fprintf('Mesh : nq=%d, nme=%d, h=%.3f\n',Th.nq,Th.get_nme(),Th.get_h())

u=@(x,y,z) cos(2*x-y-z).*sin(x-2*y+z);
U=Th.eval(u);

tstart=tic();
figure(1);
Th.plotmesh('FaceAlpha',0.5,'legend',true);
axis off;axis image
T=toc(tstart);
title(sprintf('nq=%d, nme=%d, display in %.3f(s)',Th.nq,Th.get_nme(),T))

tstart=tic();
figure(2)
Th.plotmesh('d',1,'Linewidth',2,'legend',true);
axis off;axis image
T=toc(tstart);
title(sprintf('nq=%d, nme=%d, display in %.3f(s)',Th.nq,Th.get_nme(),T))

tstart=tic();
hfig=figure(3);
Th.plot(U,'d',2)
hold on
Th.plotiso(U,'niso',15,'color',[1 1 1],'Linewidth',1)
caxis([min(U),max(U)])
axis off, axis image
shading interp
colormap(jet)
h=colorbar;
set(hfig,'Position',[0 0 800 600])
set(h,'Position',[0.75 0.25 0.025 0.50])
T=toc(tstart);
title(sprintf('nq=%d, nme=%d, display in %.3f(s)',Th.nq,Th.get_nme(),T))

tstart=tic();
hfig=figure(4);
colormap(jet)
Th.plotmesh('FaceColor',0.9*[1 1 1],'EdgeColor',0.8*[1 1 1]);
hold on
Th.plotiso(U,'niso',15,'Linewidth',1.5)
axis off, axis image
h=colorbar;
set(hfig,'Position',[0 0 800 600])
set(h,'Position',[0.75 0.25 0.025 0.50])
T=toc(tstart);
title(sprintf('nq=%d, nme=%d, display in %.3f(s)',Th.nq,Th.get_nme(),T))

tstart=tic();
hfig=figure(5);
colormap(jet)
Th.plot(U,'d',2,'labels',[1:2:8])
hold on
Th.plotiso(U,'labels',[1:2:8],'niso',15,'color',[1 1 1],'Linewidth',1)
shading interp
Th.plotmesh('labels',[2:2:8],'FaceColor',0.9*[1 1 1],'EdgeColor',0.8*[1 1 1]);
Th.plotiso(U,'labels',[2:2:8],'niso',15,'Linewidth',1.5)
axis off, axis image
Th.plotmesh('d',1,'color',[0 0 0],'Linewidth',1.5)
h=colorbar;
set(hfig,'Position',[0 0 800 600])
set(h,'Position',[0.75 0.25 0.025 0.50])
T=toc(tstart);
title(sprintf('nq=%d, nme=%d, display in %.3f(s)',Th.nq,Th.get_nme(),T))
fc_tools.graphics.DisplayFigures();